(* alist.sml

An association list data type.  (It is a good example of how
structures and signatures can be used to define the interface to an
abstract data type which can't be violated by clients.)

*)

(* the interface to assoc_lists and their operations.  the way that
   assoc_lists are represented is hidden.
 *)

signature ASSOC_LIST = sig
    type (''k,'v) assoc_list

    val empty:(''k,'v) assoc_list

    val store:(''k,'v) assoc_list * ''k * 'v -> (''k,'v) assoc_list

    val fetch:(''k,'v) assoc_list * ''k -> 'v

    val remove:(''k,'v) assoc_list * ''k -> (''k,'v) assoc_list

    val iterate:((''k * 'v) * 'a -> 'a) * 'a * (''k,'v) assoc_list -> 'a

    exception NotFound
end


(* an implementation of the assoc_list interface using lists of pairs *)

structure Assoc_List :> ASSOC_LIST = struct
    type (''k,'v) assoc_list = (''k*'v) list

    val empty = nil

    exception NotFound

    fun store(nil, key, value) = [(key,value)]
      | store((k,v)::rest, key, value) =
            if key = k then (key,value)::rest
            else (k,v)::store(rest, key, value)

    fun fetch(nil, key) = raise NotFound
      | fetch((k,v)::rest, key) =
            if key = k then v
            else fetch(rest, key)

    fun remove(nil, key) = raise NotFound
      | remove((k,v)::rest, key) =
            if key = k then rest
            else (k,v)::remove(rest, key)

    fun iterate(f, b, nil) = b
      | iterate(f, b, assoc::rest) = iterate(f, f(assoc, b), rest)
end
