open Ast
%%
%eop 	EOF
%pos 	int
%left	BAR
%left   EQUALS_GT
%left	COMMA SEMI_COLON
%left	ANDALSO ORELSE 
%left   LT LEQ GEQ GT EQUALS LT_GT 
%right	COLON_COLON
%left   PLUS MINUS CARAT
%left	TIMES DIV MOD
%right	NOT TILDE 
%right  ID
%nonassoc STR CHAR BOOL REAL INT FN LPAREN LBRACE LBRACKET LET IF CASE
%nonassoc OP
%start  TOPLEVEL

%term EOF
| ABSTYPE | AND | ANDALSO | AS | CASE | DATATYPE | DO | ELSE | END
| EQTYPE | EXCEPTION | FN | FUN | FUNCTOR | HANDLE | IF | IN | INCLUDE
| INFIX | INFIXR | LET | LOCAL | NONFIX | OF | OP | OPEN | ORELSE | RAISE
| REC | SHARING | SIG | SIGNATURE | STRUCT | STRUCTURE | THEN | TYPE | VAL
| WITH | WITHTYPE | WHERE | WHILE

| LPAREN | RPAREN | LBRACE | RBRACE | LBRACKET | RBRACKET
| COMMA | COLON | SEMI_COLON | ELIPSIS | UNDERSCORE | BAR | EQUALS | EQUALS_GT
| ARROW | HASH | DOT | COLON_GT

| NOT | DIV | MOD | TRUE | FALSE | NIL

| TILDE | PLUS | MINUS | TIMES | DIVIDE | LT | LEQ | GEQ | GT | LT_GT
| COLON_COLON | CARAT

| ID of string | TYVAR of string | OPERATOR of string
| INT of int | WORD of word | REAL of real | BOOL of bool
| CHAR of char | STR of string

| INT_TYPE | STR_TYPE | BOOL_TYPE | UNIT_TYPE | LIST_TYPE

%nonterm TOPLEVEL of TopLevel
| DEC of Decl
| FBINDS of {name:string, formal:Pattern, resType:Type option, body:Expr} list
| FBIND of {name:string, formal:Pattern, resType:Type option, body:Expr}
| EXP of Expr
| CEXP of Expr
| AEXP of Expr
| UNOP_EXP of Expr
| BINOP_EXP of Expr
| ANON_FN_CASES of {formal:Pattern, resType:Type option, body:Expr} list
| ANON_FN_CASE of {formal:Pattern, resType:Type option, body:Expr}
| EXP_COMMA_LIST of Expr list
| DECS of Decl list
| PAT of Pattern
| PAT_COMMA_LIST of Pattern list
| TYP of Type
| FTYP of Type
| TTYP of Type
| LTYP_TIMES_LIST of Type list
| LTYP of Type
| ATYP of Type

%name MiniML
    
%noshift EOF
%verbose

%%
TOPLEVEL:
  DEC                           (TopLevelDecl(DEC))
| DEC SEMI_COLON                (TopLevelDecl(DEC))
| EXP                           (TopLevelExpr(EXP))
| EXP SEMI_COLON                (TopLevelExpr(EXP))

DEC:
  VAL PAT EQUALS EXP		(ValDecl{lhs=PAT, rhs=EXP})
| FUN FBINDS			(FunDecl(FBINDS))

FBINDS:
  FBIND				([FBIND])
| FBIND BAR FBINDS		(FBIND::FBINDS)

FBIND:
  ID PAT EQUALS EXP		({name=ID,formal=PAT,resType=NONE,body=EXP})
| ID PAT COLON TYP EQUALS EXP	({name=ID,formal=PAT,resType=SOME TYP,
				  body=EXP})

EXP:
  BINOP_EXP			(BINOP_EXP)
| UNOP_EXP			(UNOP_EXP)
| CEXP				(CEXP)

UNOP_EXP:
  TILDE EXP	(UnopExpr{operator="~",arg=EXP})
| NOT EXP	(UnopExpr{operator="not",arg=EXP})

BINOP_EXP:
  EXP TIMES EXP	(BinopExpr{arg1=EXP1,operator="*",arg2=EXP2})
| EXP DIV EXP	(BinopExpr{arg1=EXP1,operator="div",arg2=EXP2})
| EXP MOD EXP	(BinopExpr{arg1=EXP1,operator="mod",arg2=EXP2})
| EXP PLUS EXP	(BinopExpr{arg1=EXP1,operator="+",arg2=EXP2})
| EXP MINUS EXP	(BinopExpr{arg1=EXP1,operator="-",arg2=EXP2})
| EXP CARAT EXP	(BinopExpr{arg1=EXP1,operator="^",arg2=EXP2})
| EXP COLON_COLON EXP	(BinopExpr{arg1=EXP1,operator="::",arg2=EXP2})
| EXP EQUALS EXP	(BinopExpr{arg1=EXP1,operator="=",arg2=EXP2})
| EXP LT_GT EXP	(BinopExpr{arg1=EXP1,operator="<>",arg2=EXP2})
| EXP LT EXP	(BinopExpr{arg1=EXP1,operator="<",arg2=EXP2})
| EXP LEQ EXP 	(BinopExpr{arg1=EXP1,operator="<=",arg2=EXP2})
| EXP GEQ EXP	(BinopExpr{arg1=EXP1,operator=">=",arg2=EXP2})
| EXP GT EXP	(BinopExpr{arg1=EXP1,operator=">",arg2=EXP2})

CEXP:
  ID CEXP		(CallExpr{function=ID,arg=CEXP})
| AEXP			(AEXP)

AEXP:
  ID				(VarExpr(ID))
| INT    			(IntExpr(INT))
| STR				(StringExpr(STR))
| BOOL		        	(BoolExpr(BOOL))
| NIL		        	(NilExpr{typ=NONE})
| NIL COLON TYP	        	(NilExpr{typ=SOME TYP})
| LPAREN RPAREN			(TupleExpr([]))
| LPAREN EXP_COMMA_LIST RPAREN	(
    let val l = EXP_COMMA_LIST
    in if List.length(l) = 1 then hd(l) else (TupleExpr(l)) end)
| LET DECS IN EXP END		(LetExpr{decls=DECS,body=EXP})
| IF EXP THEN EXP ELSE EXP	(
    IfExpr{testExpr=EXP1,thenExpr=EXP2,elseExpr=EXP3})
| FN ANON_FN_CASES              (FnExpr ANON_FN_CASES)

ANON_FN_CASES:
  ANON_FN_CASE                   ([ANON_FN_CASE])
| ANON_FN_CASE BAR ANON_FN_CASES (ANON_FN_CASE::ANON_FN_CASES)

ANON_FN_CASE:
  PAT EQUALS_GT EXP           ({formal=PAT, resType=NONE, body=EXP})
| PAT COLON TYP EQUALS_GT EXP ({formal=PAT, resType=SOME TYP, body=EXP})

EXP_COMMA_LIST:	
  EXP				([EXP])
| EXP COMMA EXP_COMMA_LIST	(EXP::EXP_COMMA_LIST)

DECS:
  DEC	       		([DEC])
| DEC SEMI_COLON	([DEC])
| DEC DECS	       	(DEC::DECS)
| DEC SEMI_COLON DECS	(DEC::DECS)

PAT:
  ID				(VarPattern{name=ID, typ=NONE})
| ID COLON TYP			(VarPattern{name=ID, typ=SOME TYP})
| UNDERSCORE			(WildcardPattern{typ=NONE})
| UNDERSCORE COLON TYP		(WildcardPattern{typ=SOME TYP})
| INT    			(IntPattern(INT))
| STR				(StringPattern(STR))
| BOOL		        	(BoolPattern(BOOL))
| NIL		        	(NilPattern{typ=NONE})
| NIL COLON TYP	        	(NilPattern{typ=SOME TYP})
| LPAREN RPAREN			(TuplePattern([]))
| LPAREN PAT_COMMA_LIST RPAREN	(
    let val l = PAT_COMMA_LIST
    in if List.length(l) = 1 then hd(l) else (TuplePattern(l)) end)
| PAT COLON_COLON PAT		(ConsPattern{head=PAT1,tail=PAT2})

PAT_COMMA_LIST:
  PAT				([PAT])
| PAT COMMA PAT_COMMA_LIST	(PAT::PAT_COMMA_LIST)

TYP:
  FTYP				(FTYP)

FTYP:
  TTYP				(TTYP)
| TTYP ARROW FTYP		(FunctionType{argType=TTYP,resType=FTYP})

TTYP:
  LTYP_TIMES_LIST		(
    let val l = LTYP_TIMES_LIST
    in if List.length(l) = 1 then hd(l) else (TupleType(l)) end)

LTYP_TIMES_LIST:
  LTYP				([LTYP])
| LTYP TIMES LTYP_TIMES_LIST	(LTYP::LTYP_TIMES_LIST)

LTYP:
  ATYP				(ATYP)
| ATYP LIST_TYPE		(ListType(ATYP))

ATYP:
  INT_TYPE			(IntType)
| STR_TYPE			(StrType)
| BOOL_TYPE			(BoolType)
| UNIT_TYPE			(UnitType)
| TYVAR				(TypeVar(TYVAR))
| LPAREN TYP RPAREN		(TYP)
